@@ -18,18 +18,13 @@ struct HttpHeader
 };
 
 /**********************************************************************************************************************************/
-HttpHeader *
-httpHeaderNew(const StringList *redactList)
+FN_EXTERN HttpHeader *
+httpHeaderNew(const StringList *const redactList)
 {
     FUNCTION_TEST_VOID();
 
-    HttpHeader *this = NULL;
-
-    OBJ_NEW_BEGIN(HttpHeader)
+    OBJ_NEW_BEGIN(HttpHeader, .childQty = MEM_CONTEXT_QTY_MAX)
     {
-        // Allocate state and set context
-        this = OBJ_NEW_ALLOC();
-
         *this = (HttpHeader)
         {
             .redactList = strLstDup(redactList),
@@ -38,42 +33,37 @@ httpHeaderNew(const StringList *redactList)
     }
     OBJ_NEW_END();
 
-    FUNCTION_TEST_RETURN(this);
+    FUNCTION_TEST_RETURN(HTTP_HEADER, this);
 }
 
 /**********************************************************************************************************************************/
-HttpHeader *
-httpHeaderDup(const HttpHeader *header, const StringList *redactList)
+FN_EXTERN HttpHeader *
+httpHeaderDup(const HttpHeader *const header, const StringList *const redactList)
 {
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(HTTP_HEADER, header);
         FUNCTION_TEST_PARAM(STRING_LIST, redactList);
     FUNCTION_TEST_END();
 
-    HttpHeader *this = NULL;
+    if (header == NULL)
+        FUNCTION_TEST_RETURN(HTTP_HEADER, NULL);
 
-    if (header != NULL)
+    OBJ_NEW_BEGIN(HttpHeader, .childQty = MEM_CONTEXT_QTY_MAX)
     {
-        OBJ_NEW_BEGIN(HttpHeader)
+        *this = (HttpHeader)
         {
-            // Allocate state and set context
-            this = OBJ_NEW_ALLOC();
-
-            *this = (HttpHeader)
-            {
-                .redactList = redactList == NULL ? strLstDup(header->redactList) : strLstDup(redactList),
-                .kv = kvDup(header->kv),
-            };
-        }
-        OBJ_NEW_END();
+            .redactList = redactList == NULL ? strLstDup(header->redactList) : strLstDup(redactList),
+            .kv = kvDup(header->kv),
+        };
     }
+    OBJ_NEW_END();
 
-    FUNCTION_TEST_RETURN(this);
+    FUNCTION_TEST_RETURN(HTTP_HEADER, this);
 }
 
 /**********************************************************************************************************************************/
-HttpHeader *
-httpHeaderAdd(HttpHeader *this, const String *key, const String *value)
+FN_EXTERN HttpHeader *
+httpHeaderAdd(HttpHeader *const this, const String *const key, const String *const value)
 {
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(HTTP_HEADER, this);
@@ -86,11 +76,11 @@ httpHeaderAdd(HttpHeader *this, const String *key, const String *value)
     ASSERT(value != NULL);
 
     // Check if the key already exists
-    const Variant *keyVar = VARSTR(key);
-    const Variant *valueVar = kvGet(this->kv, keyVar);
+    const Variant *const keyVar = VARSTR(key);
+    const Variant *const valueVar = kvGet(this->kv, keyVar);
 
-    // If the key exists then append the new value.  The HTTP spec (RFC 2616, Section 4.2) says that if a header appears more than
-    // once then it is equivalent to a single comma-separated header.  There appear to be a few exceptions such as Set-Cookie, but
+    // If the key exists then append the new value. The HTTP spec (RFC 2616, Section 4.2) says that if a header appears more than
+    // once then it is equivalent to a single comma-separated header. There appear to be a few exceptions such as Set-Cookie, but
     // they should not be of concern to us here.
     if (valueVar != NULL)
     {
@@ -108,12 +98,12 @@ httpHeaderAdd(HttpHeader *this, const String *key, const String *value)
     else
         kvPut(this->kv, keyVar, VARSTR(value));
 
-    FUNCTION_TEST_RETURN(this);
+    FUNCTION_TEST_RETURN(HTTP_HEADER, this);
 }
 
 /**********************************************************************************************************************************/
-const String *
-httpHeaderGet(const HttpHeader *this, const String *key)
+FN_EXTERN const String *
+httpHeaderGet(const HttpHeader *const this, const String *const key)
 {
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(HTTP_HEADER, this);
@@ -123,12 +113,12 @@ httpHeaderGet(const HttpHeader *this, const String *key)
     ASSERT(this != NULL);
     ASSERT(key != NULL);
 
-    FUNCTION_TEST_RETURN(varStr(kvGet(this->kv, VARSTR(key))));
+    FUNCTION_TEST_RETURN_CONST(STRING, varStr(kvGet(this->kv, VARSTR(key))));
 }
 
 /**********************************************************************************************************************************/
-StringList *
-httpHeaderList(const HttpHeader *this)
+FN_EXTERN StringList *
+httpHeaderList(const HttpHeader *const this)
 {
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(HTTP_HEADER, this);
@@ -136,12 +126,12 @@ httpHeaderList(const HttpHeader *this)
 
     ASSERT(this != NULL);
 
-    FUNCTION_TEST_RETURN(strLstSort(strLstNewVarLst(kvKeyList(this->kv)), sortOrderAsc));
+    FUNCTION_TEST_RETURN(STRING_LIST, strLstSort(strLstNewVarLst(kvKeyList(this->kv)), sortOrderAsc));
 }
 
 /**********************************************************************************************************************************/
-HttpHeader *
-httpHeaderPut(HttpHeader *this, const String *key, const String *value)
+FN_EXTERN HttpHeader *
+httpHeaderPut(HttpHeader *const this, const String *const key, const String *const value)
 {
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(HTTP_HEADER, this);
@@ -156,11 +146,11 @@ httpHeaderPut(HttpHeader *this, const String *key, const String *value)
     // Store the key
     kvPut(this->kv, VARSTR(key), VARSTR(value));
 
-    FUNCTION_TEST_RETURN(this);
+    FUNCTION_TEST_RETURN(HTTP_HEADER, this);
 }
 
 /**********************************************************************************************************************************/
-HttpHeader *
+FN_EXTERN HttpHeader *
 httpHeaderPutRange(HttpHeader *const this, const uint64_t offset, const Variant *const limit)
 {
     FUNCTION_TEST_BEGIN();
@@ -180,14 +170,15 @@ httpHeaderPutRange(HttpHeader *const this, const uint64_t offset, const Variant
             strCatFmt(range, "%" PRIu64, offset + varUInt64(limit) - 1);
 
         httpHeaderPut(this, HTTP_HEADER_RANGE_STR, range);
+        strFree(range);
     }
 
-    FUNCTION_TEST_RETURN(this);
+    FUNCTION_TEST_RETURN(HTTP_HEADER, this);
 }
 
 /**********************************************************************************************************************************/
-bool
-httpHeaderRedact(const HttpHeader *this, const String *key)
+FN_EXTERN bool
+httpHeaderRedact(const HttpHeader *const this, const String *const key)
 {
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(HTTP_HEADER, this);
@@ -197,30 +188,29 @@ httpHeaderRedact(const HttpHeader *this, const String *key)
     ASSERT(this != NULL);
     ASSERT(key != NULL);
 
-    FUNCTION_TEST_RETURN(this->redactList != NULL && strLstExists(this->redactList, key));
+    FUNCTION_TEST_RETURN(BOOL, this->redactList != NULL && strLstExists(this->redactList, key));
 }
 
 /**********************************************************************************************************************************/
-String *
-httpHeaderToLog(const HttpHeader *this)
+FN_EXTERN void
+httpHeaderToLog(const HttpHeader *const this, StringStatic *const debugLog)
 {
-    String *result = strCatZ(strNew(), "{");
-    const StringList *keyList = httpHeaderList(this);
+    const VariantList *const keyList = kvKeyList(this->kv);
 
-    for (unsigned int keyIdx = 0; keyIdx < strLstSize(keyList); keyIdx++)
+    strStcCatChr(debugLog, '{');
+
+    for (unsigned int keyIdx = 0; keyIdx < varLstSize(keyList); keyIdx++)
     {
-        const String *key = strLstGet(keyList, keyIdx);
+        const String *const key = varStr(varLstGet(keyList, keyIdx));
 
-        if (strSize(result) != 1)
-            strCatZ(result, ", ");
+        if (keyIdx != 0)
+            strStcCat(debugLog, ", ");
 
         if (httpHeaderRedact(this, key))
-            strCatFmt(result, "%s: <redacted>", strZ(key));
+            strStcFmt(debugLog, "%s: <redacted>", strZ(key));
         else
-            strCatFmt(result, "%s: '%s'", strZ(key), strZ(httpHeaderGet(this, key)));
+            strStcFmt(debugLog, "%s: '%s'", strZ(key), strZ(httpHeaderGet(this, key)));
     }
 
-    strCatZ(result, "}");
-
-    return result;
+    strStcCatChr(debugLog, '}');
 }
