@@ -7,6 +7,7 @@ Test Repo Commands
 
 #include "common/harnessConfig.h"
 #include "common/harnessInfo.h"
+#include "common/harnessStorageHelper.h"
 
 #include "info/infoArchive.h"
 #include "info/infoBackup.h"
@@ -19,22 +20,11 @@ testRun(void)
 {
     FUNCTION_HARNESS_VOID();
 
-    // *****************************************************************************************************************************
-    if (testBegin("cmdRepoCreate()"))
-    {
-        StringList *argList = strLstNew();
-        hrnCfgArgRawZ(argList, cfgOptRepoPath, TEST_PATH "/repo");
-        HRN_CFG_LOAD(cfgCmdRepoCreate, argList);
-
-        // -------------------------------------------------------------------------------------------------------------------------
-        TEST_TITLE("noop on non-S3 storage");
-
-        TEST_RESULT_VOID(cmdRepoCreate(), "repo create");
-    }
-
     // *****************************************************************************************************************************
     if (testBegin("cmdStorageList() and storageListRender()"))
     {
+        hrnStorageHelperRepoShimSet(true);
+
         StringList *argList = strLstNew();
         hrnCfgArgRawZ(argList, cfgOptRepoPath, TEST_PATH "/repo");
         hrnCfgArgRawZ(argList, cfgOptOutput, "text");
@@ -54,9 +44,11 @@ testRun(void)
         TEST_RESULT_VOID(storageListRender(ioBufferWriteNew(output)), "missing directory (json)");
         TEST_RESULT_STR_Z(
             strNewBuf(output),
-                "{"
-                    "\".\":{\"type\":\"path\"}"
-                "}\n",
+            // {uncrustify_off - indentation}
+            "{"
+                "\".\":{\"type\":\"path\"}"
+            "}\n",
+            // {uncrustify_on}
             "check output");
 
         // -------------------------------------------------------------------------------------------------------------------------
@@ -74,9 +66,11 @@ testRun(void)
         TEST_RESULT_VOID(storageListRender(ioBufferWriteNew(output)), "empty directory (json)");
         TEST_RESULT_STR_Z(
             strNewBuf(output),
-                "{"
-                    "\".\":{\"type\":\"path\"}"
-                "}\n",
+            // {uncrustify_off - indentation}
+            "{"
+                "\".\":{\"type\":\"path\"}"
+            "}\n",
+            // {uncrustify_on}
             "check output");
 
         output = bufNew(0);
@@ -84,9 +78,11 @@ testRun(void)
         TEST_RESULT_VOID(storageListRender(ioBufferWriteNew(output)), "empty directory with filter match (json)");
         TEST_RESULT_STR_Z(
             strNewBuf(output),
-                "{"
-                    "\".\":{\"type\":\"path\"}"
-                "}\n",
+            // {uncrustify_off - indentation}
+            "{"
+                "\".\":{\"type\":\"path\"}"
+            "}\n",
+            // {uncrustify_on}
             "check output");
 
         output = bufNew(0);
@@ -96,6 +92,18 @@ testRun(void)
 
         cfgOptionSet(cfgOptFilter, cfgSourceParam, NULL);
 
+        // -------------------------------------------------------------------------------------------------------------------------
+        TEST_TITLE("exact repo path");
+
+        StringList *argListTmp = strLstDup(argList);
+        strLstAddZ(argListTmp, TEST_PATH "/repo");
+        HRN_CFG_LOAD(cfgCmdRepoLs, argListTmp);
+
+        output = bufNew(0);
+        cfgOptionSet(cfgOptOutput, cfgSourceParam, VARUINT64(CFGOPTVAL_OUTPUT_TEXT));
+        TEST_RESULT_VOID(storageListRender(ioBufferWriteNew(output)), "empty directory (text)");
+        TEST_RESULT_STR_Z(strNewBuf(output), "", "check output");
+
         // -------------------------------------------------------------------------------------------------------------------------
         TEST_TITLE("add path and file");
 
@@ -118,15 +126,19 @@ testRun(void)
         TEST_RESULT_VOID(storageListRender(ioBufferWriteNew(output)), "path and file (json)");
         TEST_RESULT_STR_Z(
             strNewBuf(output),
-                "{"
-                    "\".\":{\"type\":\"path\"},"
-                    "\"aaa\":{\"type\":\"file\",\"size\":8,\"time\":1578671569},"
-                    "\"bbb\":{\"type\":\"path\"},"
-                    "\"link\":{\"type\":\"link\",\"destination\":\"../bbb\"},"
-                    "\"pipe\":{\"type\":\"special\"}"
-                "}\n",
+            // {uncrustify_off - indentation}
+            "{"
+                "\".\":{\"type\":\"path\"},"
+                "\"aaa\":{\"type\":\"file\",\"size\":8,\"time\":1578671569},"
+                "\"bbb\":{\"type\":\"path\"},"
+                "\"link\":{\"type\":\"link\",\"destination\":\"../bbb\"},"
+                "\"pipe\":{\"type\":\"special\"}"
+            "}\n",
+            // {uncrustify_on}
             "check output");
 
+        HRN_SYSTEM("rm -f " TEST_PATH "/repo/link " TEST_PATH "/repo/pipe");
+
         // -------------------------------------------------------------------------------------------------------------------------
         TEST_TITLE("reverse sort");
 
@@ -135,17 +147,17 @@ testRun(void)
         output = bufNew(0);
         cfgOptionSet(cfgOptOutput, cfgSourceParam, VARUINT64(CFGOPTVAL_OUTPUT_TEXT));
         TEST_RESULT_VOID(storageListRender(ioBufferWriteNew(output)), "path and file (text)");
-        TEST_RESULT_STR_Z(strNewBuf(output), "pipe\nlink\nbbb\naaa\n", "check output");
+        TEST_RESULT_STR_Z(strNewBuf(output), "bbb\naaa\n", "check output");
 
         // -------------------------------------------------------------------------------------------------------------------------
         TEST_TITLE("recurse");
 
-        cfgOptionSet(cfgOptRecurse, cfgSourceParam, VARBOOL(true));
+        cfgOptionSet(cfgOptRecurse, cfgSourceParam, BOOL_TRUE_VAR);
 
         output = bufNew(0);
         cfgOptionSet(cfgOptOutput, cfgSourceParam, VARUINT64(CFGOPTVAL_OUTPUT_TEXT));
         TEST_RESULT_VOID(storageListRender(ioBufferWriteNew(output)), "filter");
-        TEST_RESULT_STR_Z(strNewBuf(output), "pipe\nlink\nbbb/ccc\nbbb\naaa\n", "check output");
+        TEST_RESULT_STR_Z(strNewBuf(output), "bbb/ccc\nbbb\naaa\n", "check output");
 
         // -------------------------------------------------------------------------------------------------------------------------
         TEST_TITLE("filter");
@@ -160,12 +172,34 @@ testRun(void)
         // -------------------------------------------------------------------------------------------------------------------------
         TEST_TITLE("error on /");
 
-        StringList *argListTmp = strLstDup(argList);
+        argListTmp = strLstDup(argList);
         strLstAddZ(argListTmp, "/");
         HRN_CFG_LOAD(cfgCmdRepoLs, argListTmp);
 
         TEST_ERROR(
-            storageListRender(ioBufferWriteNew(output)), AssertError, "absolute path '/' is not in base path '" TEST_PATH "/repo'");
+            storageListRender(ioBufferWriteNew(output)), ParamInvalidError,
+            "absolute path '/' is not in base path '" TEST_PATH "/repo'");
+
+        // -------------------------------------------------------------------------------------------------------------------------
+        TEST_TITLE("error on path that starts with repo path");
+
+        argListTmp = strLstDup(argList);
+        strLstAddZ(argListTmp, TEST_PATH "/reposub");
+        HRN_CFG_LOAD(cfgCmdRepoLs, argListTmp);
+
+        TEST_ERROR(
+            storageListRender(ioBufferWriteNew(output)), ParamInvalidError,
+            "absolute path '" TEST_PATH "/reposub' is not in base path '" TEST_PATH "/repo'");
+
+        // -------------------------------------------------------------------------------------------------------------------------
+        TEST_TITLE("error on //");
+
+        argListTmp = strLstDup(argList);
+        strLstAddZ(argListTmp, "bbb//");
+        HRN_CFG_LOAD(cfgCmdRepoLs, argListTmp);
+
+        TEST_ERROR(
+            storageListRender(ioBufferWriteNew(output)), ParamInvalidError, "path 'bbb//' cannot contain //");
 
         // -------------------------------------------------------------------------------------------------------------------------
         TEST_TITLE("subdirectory");
@@ -204,7 +238,7 @@ testRun(void)
         // Close the fd to make sure the error gets caught
         close(STDOUT_FILENO);
 
-        // // Not in a test wrapper to avoid writing to stdout
+        // Not in a test wrapper to avoid writing to stdout
         cmdStorageList();
 
         // Restore normal stdout
@@ -234,9 +268,11 @@ testRun(void)
         TEST_RESULT_VOID(storageListRender(ioBufferWriteNew(output)), "file (json)");
         TEST_RESULT_STR_Z(
             strNewBuf(output),
-                "{"
-                    "\".\":{\"type\":\"file\",\"size\":8,\"time\":1578671569}"
-                "}\n",
+            // {uncrustify_off - indentation}
+            "{"
+                "\".\":{\"type\":\"file\",\"size\":8,\"time\":1578671569}"
+            "}\n",
+            // {uncrustify_on}
             "check output");
 
         output = bufNew(0);
@@ -244,15 +280,42 @@ testRun(void)
         TEST_RESULT_VOID(storageListRender(ioBufferWriteNew(output)), "file (json)");
         TEST_RESULT_STR_Z(
             strNewBuf(output),
-                "{"
-                    "\".\":{\"type\":\"file\",\"size\":8,\"time\":1578671569}"
-                "}\n",
+            // {uncrustify_off - indentation}
+            "{"
+                "\".\":{\"type\":\"file\",\"size\":8,\"time\":1578671569}"
+            "}\n",
+            // {uncrustify_on}
             "check output");
 
         output = bufNew(0);
         cfgOptionSet(cfgOptFilter, cfgSourceParam, VARSTRDEF("bbb$"));
         TEST_RESULT_VOID(storageListRender(ioBufferWriteNew(output)), "file (json)");
         TEST_RESULT_STR_Z(strNewBuf(output), "{}\n", "check output");
+
+        // -------------------------------------------------------------------------------------------------------------------------
+        TEST_TITLE("target time");
+
+        argList = strLstNew();
+        hrnCfgArgRawZ(argList, cfgOptRepoPath, TEST_PATH "/repo");
+        hrnCfgArgRawZ(argList, cfgOptOutput, "json");
+        hrnCfgArgRawZ(argList, cfgOptRepo, "1");
+        hrnCfgArgRawZ(argList, cfgOptRepoTargetTime, "2024-08-04 02:54:09+00");
+        HRN_CFG_LOAD(cfgCmdRepoLs, argList);
+
+        output = bufNew(0);
+        TEST_RESULT_VOID(storageListRender(ioBufferWriteNew(output)), "file (json)");
+        TEST_RESULT_STR_Z(
+            strNewBuf(output),
+            // {uncrustify_off - indentation}
+            "{"
+                "\".\":{\"type\":\"path\"},"
+                "\"aaa\":{\"type\":\"file\",\"size\":8,\"time\":1578671569,\"version\":\"v0001\"},"
+                "\"bbb\":{\"type\":\"path\"}"
+            "}\n",
+            // {uncrustify_on}
+            "check output");
+
+        hrnStorageHelperRepoShimSet(false);
     }
 
     // *****************************************************************************************************************************
@@ -425,9 +488,9 @@ testRun(void)
         // -------------------------------------------------------------------------------------------------------------------------
         TEST_TITLE("put encrypted WAL archive file");
 
-        // Create WAL segment
+        // Create WAL segment. Keep it small since encryption/decryption takes time (esp on 32-bit).
         ioBufferSizeSet(oldBufferSize);
-        Buffer *archiveFileBuffer = bufNew(16 * 1024 * 1024);
+        Buffer *archiveFileBuffer = bufNew(1024);
         memset(bufPtr(archiveFileBuffer), 0, bufSize(archiveFileBuffer));
         bufUsedSet(archiveFileBuffer, bufSize(archiveFileBuffer));
 
@@ -488,7 +551,7 @@ testRun(void)
         hrnCfgArgRawZ(argList, cfgOptRepoPath, TEST_PATH "/repo");
         hrnCfgArgRawStrId(argList, cfgOptRepoCipherType, cipherTypeAes256Cbc);
         hrnCfgArgRawZ(argList, cfgOptCipherPass, "custom2");
-        strLstAdd(argList, STRDEF(STORAGE_PATH_BACKUP "/test/latest/pg_data/backup_label"));
+        strLstAddZ(argList, STORAGE_PATH_BACKUP "/test/latest/pg_data/backup_label");
         HRN_CFG_LOAD(cfgCmdRepoPut, argList);
 
         TEST_RESULT_VOID(storagePutProcess(ioBufferReadNew(backupLabelBuffer)), "put");
@@ -517,7 +580,7 @@ testRun(void)
 
         argList = strLstNew();
         hrnCfgArgRawZ(argList, cfgOptRepoPath, "/");
-        strLstAdd(argList, strNewFmt(TEST_PATH "/repo/%s", strZ(fileName)));
+        strLstAddFmt(argList, TEST_PATH "/repo/%s", strZ(fileName));
         HRN_CFG_LOAD(cfgCmdRepoGet, argList);
 
         writeBuffer = bufNew(0);
@@ -594,7 +657,7 @@ testRun(void)
 
         writeBuffer = bufNew(0);
         TEST_ERROR(
-            storageGetProcess(ioBufferWriteNew(writeBuffer)), OptionInvalidValueError,
+            storageGetProcess(ioBufferWriteNew(writeBuffer)), ParamInvalidError,
             "absolute path '/somewhere/" INFO_ARCHIVE_FILE "' is not in base path '" TEST_PATH "/repo'");
 
         // -------------------------------------------------------------------------------------------------------------------------
@@ -609,7 +672,7 @@ testRun(void)
         writeBuffer = bufNew(0);
         TEST_ERROR(
             storageGetProcess(ioBufferWriteNew(writeBuffer)), OptionInvalidValueError,
-            strZ(strNewFmt("unable to determine cipher passphrase for '%s'", strZ(fileEncCustomName))));
+            zNewFmt("unable to determine cipher passphrase for '%s'", strZ(fileEncCustomName)));
 
         // -------------------------------------------------------------------------------------------------------------------------
         TEST_TITLE("get encrypted archive.info - stanza mismatch");
@@ -690,11 +753,9 @@ testRun(void)
         argList = strLstNew();
         hrnCfgArgRawZ(argList, cfgOptRepoPath, TEST_PATH "/repo");
         hrnCfgArgRawStrId(argList, cfgOptRepoCipherType, cipherTypeAes256Cbc);
-        strLstAdd(
-            argList,
-            strNewFmt(
-                "%s/repo/" STORAGE_PATH_ARCHIVE "/test/12-1/000000010000000100000001-aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa",
-                TEST_PATH));
+        strLstAddFmt(
+            argList, "%s/repo/" STORAGE_PATH_ARCHIVE "/test/12-1/000000010000000100000001-aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa",
+            TEST_PATH);
         HRN_CFG_LOAD(cfgCmdRepoGet, argList);
 
         writeBuffer = bufNew(0);
@@ -746,7 +807,7 @@ testRun(void)
         argList = strLstNew();
         hrnCfgArgRawZ(argList, cfgOptRepoPath, TEST_PATH "/repo");
         hrnCfgArgRawStrId(argList, cfgOptRepoCipherType, cipherTypeAes256Cbc);
-        strLstAdd(argList, STRDEF(STORAGE_PATH_BACKUP "/test/latest/pg_data/backup_label"));
+        strLstAddZ(argList, STORAGE_PATH_BACKUP "/test/latest/pg_data/backup_label");
         HRN_CFG_LOAD(cfgCmdRepoGet, argList);
 
         writeBuffer = bufNew(0);
